@@ -7,8 +7,7 @@ use File::Spec;
 use File::Find;
 use File::Spec::Functions qw(catdir catfile rel2abs);
 use File::Temp;
-use Capture::Tiny;
-use Config;
+use ExtUtils::CBuilder;
 
 =head1 NAME
 
@@ -16,11 +15,11 @@ Alien::SDL - building, finding and using SDL binaries
 
 =head1 VERSION
 
-Version 1.445_2
+Version 1.1
 
 =cut
 
-our $VERSION = '1.445_2';
+our $VERSION = '1.1';
 $VERSION = eval $VERSION;
 
 =head1 SYNOPSIS
@@ -29,33 +28,19 @@ Alien::SDL tries (in given order) during its installation:
 
 =over
 
-=item * When given C<--with-sdl-config> option use specified sdl-config
-script to locate SDL libs.
-
- perl Build.PL --with-sdl-config=/opt/sdl/bin/sdl-config
-
-or use the default script named 'sdl-config' by running:
-
- perl Build.PL --with-sdl-config
-
-B<IMPORTANT NOTE:> Using --with-sdl-config avoids considering any other
-build methods; no prompt with other available build options.
-
 =item * Locate an already installed SDL via 'sdl-config' script.
 
 =item * Check for SDL libs in directory specified by SDL_INST_DIR variable.
 In this case the module performs SDL library detection via
 '$SDL_INST_DIR/bin/sdl-config' script.
 
- SDL_INST_DIR=/opt/sdl perl ./Build.PL
-
 =item * Download prebuilt SDL binaries (if available for your platform).
 
 =item * Build SDL binaries from source codes (if possible on your system).
 
 =back
 
-Later you can use Alien::SDL in your module that needs to link against SDL
+Later you can use Alien::SDL in your module that needs to link agains SDL
 and/or related libraries like this:
 
     # Sample Makefile.pl
@@ -65,7 +50,7 @@ and/or related libraries like this:
     WriteMakefile(
       NAME         => 'Any::SDL::Module',
       VERSION_FROM => 'lib/Any/SDL/Module.pm',
-      LIBS         => Alien::SDL->config('libs', [-lAdd_Lib]),
+      LIBS         => Alien::SDL->config('libs'),
       INC          => Alien::SDL->config('cflags'),
       # + additional params
     );
@@ -77,7 +62,7 @@ Please see L<Alien> for the manifesto of the Alien namespace.
 In short C<Alien::SDL> can be used to detect and get
 configuration settings from an installed SDL and related libraries.
 Based on your platform it offers the possibility to download and
-install prebuilt binaries or build SDL & co. from source codes.
+install prebuilt binaries or to build SDL & co. from source codes.
 
 The important facts:
 
@@ -90,14 +75,14 @@ installation on your system.
 reinstall Alien::SDL (providing that you use the same directory for
 the new installation).
 
-=item * The prebuilt binaries and/or binaries built from sources are always
+=item * The prebuild binaries and/or binaries built from sources are always
 installed into perl module's 'share' directory.
 
-=item * If you use the prebuilt binaries and/or binaries built from sources
+=item * If you use prebuild binaries and/or binaries built from sources
 it happens that some of the dynamic libraries (*.so, *.dll) will not
-be automatically loadable as they will be stored somewhere under the perl
-module's 'share' directory. To handle this scenario Alien::SDL offers some
-special functionality (see below).
+automaticly loadable as they will be stored somewhere under perl module's
+'share' directory. To handle this scenario Alien::SDL offers some special
+functionality (see below).
 
 =back
 
@@ -133,7 +118,7 @@ where '<libnick>' is shortname for SDL related library like: SDL, SDL_gfx, SDL_n
 SDL_sound ... + some non-SDL shortnames e.g. smpeg, jpeg, png.
 
 NOTE: config('ld_<something>') return an empty list/hash if you have decided to
-use SDL libraries already installed on your system. This concerns 'sdl-config'
+use SDL libraries already installed on your system. This concerns 'sdl-config' 
 detection and detection via '$SDL_INST_DIR/bin/sdl-config'.
 
 =head2 check_header()
@@ -190,10 +175,9 @@ LICENSE file included with this module.
 ### get config params
 sub config
 {
-  my $package = shift;
-  my @params  = @_;
-  return _sdl_config_via_script(@params)      if(Alien::SDL::ConfigData->config('script'));
-  return _sdl_config_via_config_data(@params) if(Alien::SDL::ConfigData->config('config'));
+  my ($package, $param) = @_;
+  return _sdl_config_via_script($param) if(Alien::SDL::ConfigData->config('script'));
+  return _sdl_config_via_config_data($param) if(Alien::SDL::ConfigData->config('config'));
 }
 
 ### get version info from given header file
@@ -219,7 +203,7 @@ sub get_header_version {
   $v_maj =~ s/^#define[ \t]+[A-Z_]+[ \t]+([0-9]+)[.\r\n]*$/$1/;
   my ($v_min) = grep(/^#define[ \t]+[A-Z_]+MINOR[A-Z_]*[ \t]+[0-9]+/, @raw);
   $v_min =~ s/^#define[ \t]+[A-Z_]+[ \t]+([0-9]+)[.\r\n]*$/$1/;
-  my ($v_pat) = grep(/^#define[ \t]+[A-Z_]+(PATCHLEVEL|MICRO|RELEASE)[A-Z_]*[ \t]+[0-9]+/, @raw);
+  my ($v_pat) = grep(/^#define[ \t]+[A-Z_]+(PATCHLEVEL|MICRO)[A-Z_]*[ \t]+[0-9]+/, @raw);
   $v_pat =~ s/^#define[ \t]+[A-Z_]+[ \t]+([0-9]+)[.\r\n]*$/$1/;
   return if (($v_maj eq '')||($v_min eq '')||($v_pat eq ''));
   return "$v_maj.$v_min.$v_pat";
@@ -228,27 +212,13 @@ sub get_header_version {
 ### check presence of header(s) specified as params
 sub check_header {
   my ($package, @header) = @_;
-  print STDERR "[$package] Testing header(s): " . join(', ', @header);
-
-  require ExtUtils::CBuilder; # PAR packer workaround
-
-  my $config = {};
-  if($^O eq 'cygwin') {
-    my $ccflags = $Config{ccflags};
-    $ccflags    =~ s/-fstack-protector//;
-    $config     = { ld => 'gcc', cc => 'gcc', ccflags => $ccflags };
-  }
-
-  my $cb = ExtUtils::CBuilder->new( quiet => 1, config => $config );
-  my ($fs, $src) = File::Temp::tempfile('aaXXXX', SUFFIX => '.c', UNLINK => 1);
+  print STDERR "[$package] Testing header(s): " . join(', ', @header) . "\n";
+  my $cb = ExtUtils::CBuilder->new(quiet => 1);
+  my ($fs, $src) = File::Temp->tempfile('XXXXaa', SUFFIX => '.c', UNLINK => 1);
   my $inc = '';
-  my $i = 0;
-  foreach (@header) {
-    @header = (splice(@header, 0, $i) , 'stdio.h', splice(@header, $i)) if $_ eq 'jpeglib.h';
-    $i++;
-  }
-  $inc .= "#include <$_>\n" for @header;
+  $inc .= "#include <$_>\n" for @header;  
   syswrite($fs, <<MARKER); # write test source code
+#include <stdio.h>
 #if defined(_WIN32) && !defined(__CYGWIN__)
 /* GL/gl.h on Win32 requires windows.h being included before */
 #include <windows.h>
@@ -258,32 +228,16 @@ int demofunc(void) { return 0; }
 
 MARKER
   close($fs);
-  my $obj;
-  my $stdout = '';
-  my $stderr = '';
-  ($stdout, $stderr) = Capture::Tiny::capture {
-    $obj = eval { $cb->compile( source => $src, extra_compiler_flags => Alien::SDL->config('cflags')); };
-  };
-
+  #open OLDERR, ">&STDERR";
+  #open STDERR, ">", File::Spec->devnull();  
+  my $obj = eval { $cb->compile( source => $src, extra_compiler_flags => Alien::SDL->config('cflags')); };
+  #open(STDERR, ">&OLDERR");
   if($obj) {
-    print STDERR "\n";
     unlink $obj;
     return 1;
   }
   else {
-    if( $stderr ) {
-      $stderr =~ s/[\r\n]$//;
-      $stderr =~ s/^\Q$src\E[\d\s:]*//;
-      print STDERR " NOK: ($stderr)\n";
-    }
-    # on Windows (MSVC) stdout is set, but not stderr
-    else {
-      $stdout =~ s/[\r\n]$//;
-      $stdout =~ s/.+[\r\n]//;
-      $stdout =~ s/^\Q$src\E[\(\)\d\s:]*//;
-      print STDERR " NOK: ($stdout)\n";
-    }
-
+    print STDERR "###TEST FAILED### for: " . join(', ', @header) . "\n";
     return 0;
   }
 }
@@ -291,8 +245,7 @@ MARKER
 ### internal functions
 sub _sdl_config_via_script
 {
-  my $param    = shift;
-  my @add_libs = @_;
+  my ($param) = @_;
   my $devnull = File::Spec->devnull();
   my $script = Alien::SDL::ConfigData->config('script');
   return unless ($script && ($param =~ /[a-z0-9_]*/i));
@@ -302,19 +255,14 @@ sub _sdl_config_via_script
     $val .= ' ' . Alien::SDL::ConfigData->config('additional_cflags');
   }
   elsif($param eq 'libs') {
-    $val .= ' ' . join(' ', @add_libs) if scalar @add_libs;
     $val .= ' ' . Alien::SDL::ConfigData->config('additional_libs');
   }
-  elsif($param =~ /^(ld_shlib_map|ld_shared_libs|ld_paths)$/) {
-    $val = Alien::SDL::ConfigData->config('config')->{$param};
-  }
   return $val;
 }
 
 sub _sdl_config_via_config_data
 {
-  my $param    = shift;
-  my @add_libs = @_;
+  my ($param) = @_;
   my $share_dir = dist_dir('Alien-SDL');
   my $subdir = Alien::SDL::ConfigData->config('share_subdir');
   return unless $subdir;
@@ -327,9 +275,8 @@ sub _sdl_config_via_config_data
     $val .= ' ' . Alien::SDL::ConfigData->config('additional_cflags');
   }
   elsif($param eq 'libs') {
-    $val .= ' ' . join(' ', @add_libs) if scalar @add_libs;
     $val .= ' ' . Alien::SDL::ConfigData->config('additional_libs');
-  }
+  }  
   # handle @PrEfIx@ replacement
   if ($param =~ /^(ld_shared_libs|ld_paths)$/) {
     s/\@PrEfIx\@/$real_prefix/g foreach (@{$val});
